@@ -473,9 +473,10 @@ def shell(command: str, ip: Optional[str] = None, **kwargs) -> ADBCommandResult:
     """
     ip_arg = f"-s {ip} " if ip else ""
     adb = get_adb_path()
-    command_line = f"{ip_arg} shell {command} {get_extra_arguments(**kwargs)}"
-    command_full = f"{adb} {command_line}".strip()
-    command_log = f"adb {command_line}".strip()
+    command_line = f"{ip_arg} shell"
+    command_args = f"{command} {get_extra_arguments(**kwargs)}"
+    command_full = f"{adb} {command_line} {command_args}".strip()
+    command_log = f"adb {command_line} {command_args}".strip()
     log().debug(f"Executing `{command_log}`")
 
     out = subprocess.Popen(
